pub struct ServiceConfig {
pub service_name: String,
pub instance_name: String,
pub port: u16,
pub addrs: Vec<IpAddr>,
pub txt: Vec<(String, String)>,
pub protocol: Protocol,
}Expand description
Canonical description of a DNS-SD advertisement.
Fields
service_name: StringBare service label, without the leading underscore or protocol/domain.
instance_name: StringHuman-visible DNS-SD instance label.
port: u16SRV port.
addrs: Vec<IpAddr>Explicit addresses in addition to addresses supplied by the transport.
txt: Vec<(String, String)>TXT properties. Order is retained across the transport boundary.
protocol: ProtocolDNS-SD transport protocol.